# coolpy

This is a project demonstrating how publich a muon beam cooling module to PyPI

##Installation

Run the following to install:

'''python pip install coolpy'''

##Usage

'''python 
from coolpy import quadrupole

## Generate "Qudarupole matrix!"

'''

# Developing Hello World

To install coolpy, aling with the tool you need to develop and run tests, run the following in you r virtualenv:

'''bash
$ pip install -e .[dev]
'''
